#ifndef DISPATCHER_H
#define DISPATCHER_H

#include <QString>
#include <QUrl>

#include "playlistloop.h"
#include "ui/widgets/runnable.h"
#include "ui/viewer.h"
#include "settings.h"

class Dispatcher : public QObject
{
    Q_OBJECT

public:
    Dispatcher(Viewer *viewer, QString path = QString()); // path is a dbus path

public slots:
    void next();

private:
    enum Status {
        StatusNone = 0,
        StatusBrowser,
        StatusAfterBrowser,
        StatusPlaylist
    };

    Settings *settings;

    Dispatcher::Status m_status;
    Runnable *m_currentWidget;
    Runnable *m_prevWidget;
    QString m_mode;
    Viewer *m_viewer;

    PlaylistLoop *m_loop;
    int m_loopIdx;

    QTimer m_ssTimer;
    void disableScreensaver();

    void StartSession();
    void StopSession();
    void AddTime(int seconds);

    void startup();
    void reconnectMouseEvent();
    void afterBrowser();
    void startBrowser();
    void execHook(QString hook);
    void startSlideshow();

private slots:
    void onReconnectMouseEventTimeout();
    void onScreensaverTimeout();
    void onMouseEvent();
    void showLoopNext();
};

#endif
