#ifndef DOWNLOADER_H
#define DOWNLOADER_H

#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QString>
#include <QObject>
#include <QList>
#include <QFile>
#include <QFileInfo>

#include "settings.h"
#include "playlistitem.h"
#include "playlistloop.h"

class ItemDownloader : public QObject
{
    Q_OBJECT

public:
    ItemDownloader(QString uri, QString dest);
    ~ItemDownloader();
    void start();

private:
    QString m_uri;
    QFile m_file;
    QNetworkRequest m_request;
    QNetworkReply *m_reply;
    QNetworkAccessManager *m_nam;

    QString etag();

private slots:
    void onReadyRead();
    void onFinished();

signals:
    void finished();
};


class Downloader : public QObject
{
    Q_OBJECT

public:
    Downloader(PlaylistLoop *loop);
    ~Downloader();
    void start();

private:
    PlaylistLoop *m_loop;
    QString m_baseUrl;
    QString m_cacheDir;
    QString m_dataDir;
    QString m_etagDir;

    ItemDownloader *m_idl;
    int m_index;

    QString localEtag(QString url);
    void writeEtag(QString url, int d, int s);
    bool checkEtag(QString url, int d, int s);

private slots:
    void downloadNext();

signals:
    void downloadDone();
};

#endif
