#include <QApplication>
#include <QNetworkProxyFactory>
#include <QIcon>
#include <QDebug>

#ifdef Q_WS_X11
    #include <X11/Xlib.h>
#endif

#include "dispatcher.h"
#include "ui/viewer.h"
#include "proxyfactory.h"
#include "settings.h"
#include "logger.h"
#include "utils.h"
#include "config.h"

int main(int argc, char **argv)
{
#ifdef Q_WS_X11
        XInitThreads();
#endif

    QApplication app(argc, argv);
    app.setApplicationName("linutop-webkiosk");
    app.setOrganizationName("Linutop");
    app.setOrganizationDomain("linutop.com");

    app.quitOnLastWindowClosed();

    Logger::init();

    QIcon::setThemeName(Utils::getIconTheme());

    ProxyFactory *factory = new ProxyFactory;
    QNetworkProxyFactory::setApplicationProxyFactory(factory);

    Viewer v;
    Dispatcher d(&v);
    d.next();
    v.show();

    int r = app.exec();

    Logger::shutdown();

    delete factory;

    return r;
}
