#ifndef BROWSER_H
#define BROWSER_H

#include <QTabWidget>
#include <QStatusBar>
#include <QPushButton>
#include <QVBoxLayout>
#include <QLabel>
#include <QTimer>

#include "ui/widgets/runnable.h"
#include "processmanager.h"
#include "page.h"
#include "settings.h"

class Browser : public QWidget, public Runnable
{
    Q_OBJECT
    Q_INTERFACES(Runnable)

public:
    Browser(QWidget *parent = 0);
    ~Browser();
    void run();
    void stop();
    void addTime(int seconds);

private:
    Settings *settings;

    QTabWidget m_tabWidget;
    QStatusBar m_statusBar;
    QVBoxLayout m_layout;
    QPushButton m_cornerBtn;
    QList<Page *> m_pages;
    QUrl home;

    int downloads;
    QLabel m_downloadLabel;

    int remaining;
    QTimer m_timer;
    QLabel m_timerLabel;

    SubprocessManager m_processManager;

    void setShortcuts();
    void setHome(QString url);
    void setupPage(Page *p, QUrl url = QUrl());

private slots:
    void onTimeout();
    void onTitleChanged(QString, Page *);
    void onTabCloseRequested(int);
    void onDownloadStarted();
    void onDownloadDone(QString filepath, QString mimetype);
    void nextTab();
    void prevTab();
    void selectAddressBar();
    void selectAddressBarAndBeginSearch();
    void onUrlDenied(QString);
    Page *newPage(QUrl url = QUrl());
    Page *newPage(RestrictedWebView *webview);
    void onMouseMove();
    void onEnd();
    void onWebViewCreated(RestrictedWebView *);

signals:
    void end();
    void mouseMoved();
    void timeAdded(int);
};

#endif
