#include <QWebHistory>
#include <QIcon>
#include <QAction>
#include <QMessageBox>

#include "navbar.h"

NavBar::NavBar(RestrictedWebView *view, QWidget *parent)
    : QToolBar(parent)
{
    QAction *action;

    m_view = view;
    settings = Settings::load();

    m_locationEdit = new LocationEdit(this);
    m_locationEdit->setSizePolicy(QSizePolicy::Expanding,
                                  m_locationEdit->sizePolicy().verticalPolicy());
    connect(m_locationEdit, SIGNAL(returnPressed()),
            this, SLOT(onLocationChanged()));

    action = addAction(QIcon::fromTheme("user-home"), "Home");
    connect(action, SIGNAL(triggered()), this, SLOT(onGoHome()));
    addAction(m_view->pageAction(QWebPage::Back));
    addAction(m_view->pageAction(QWebPage::Forward));
    addAction(m_view->pageAction(QWebPage::Stop));
    addWidget(m_locationEdit);
    action = addAction(QIcon::fromTheme("stock_media-play"), "Go");
    connect(action, SIGNAL(triggered()), this, SLOT(onLocationChanged()));
    addAction(m_view->pageAction(QWebPage::Reload));
    if (settings->get("main/can_end_session").toBool())
    {
        action = addAction(QIcon::fromTheme("gtk-clear"), "Clear");
        connect(action, SIGNAL(triggered()), this, SLOT(onEnd()));
    }

    connect(m_view, SIGNAL(loadFinished(bool)), this, SLOT(adjustLocation(bool)));
    connect(m_view, SIGNAL(titleChanged(QString)), this, SLOT(adjustTitle(QString)));
    connect(m_view, SIGNAL(loadProgress(int)), this, SLOT(setProgress(int)));
}

void NavBar::adjustLocation(bool ok)
{
    m_locationEdit->setText(m_view->url().toString());
}

void NavBar::adjustTitle(QString title)
{
    if (title.isEmpty())
        title = m_view->url().path();
    emit(titleChanged(title));
}

void NavBar::setProgress(int i)
{
    m_locationEdit->setProgress(i);
}

void NavBar::onGoHome()
{
    m_view->home();
}

void NavBar::setHistoryStatus()
{
    bool b;
    
    b = m_view->history()->canGoBack();
    m_view->pageAction(QWebPage::Back)->setEnabled(b);

    b = m_view->history()->canGoForward();
    m_view->pageAction(QWebPage::Forward)->setEnabled(b);
}

void NavBar::onLocationChanged()
{
    QUrl url;
    QString txt = m_locationEdit->text().simplified();
    if (!txt.isEmpty() && (txt.at(0) == '?'))
    {
        txt = txt.right(1).replace(QString(" "), QString("+"));
        url = QUrl(QString("http://www.google.com/search?q=%1").arg(txt));
    }
    else
    {
        url = QUrl::fromUserInput(txt);
    }
    m_view->load(url);
    m_view->setFocus();
}

void NavBar::onEnd()
{
    QMessageBox::StandardButton ret;
    ret = QMessageBox::warning(this, "End the web session",
            "Your session will be terminated.\n\nDo you really want to continue?",
            QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
    if (ret == QMessageBox::Yes)
        emit(end());
}
