#include <QWebFrame>
#include <QWebElementCollection>
#include <QVBoxLayout>

#include "page.h"

Page::Page(QUrl url, QWidget *parent)
    : QWidget(parent)
{
    settings = Settings::load();

    m_view = new RestrictedWebView(url);
    connect(m_view, SIGNAL(urlDenied(QString)), this, SLOT(onUrlDenied(QString)));

    setup();
}

Page::Page(RestrictedWebView *webView, QWidget *parent)
{
    settings = Settings::load();
    m_view = webView;

    setup();
}

void Page::setup()
{
    m_navbar = new NavBar(m_view, this);
    connect(m_navbar, SIGNAL(titleChanged(QString)), this, SLOT(adjustTitle(QString)));
    connect(m_navbar, SIGNAL(end()), this, SLOT(onEnd()));

    QVBoxLayout *layout = new QVBoxLayout;
    layout->setContentsMargins(0, 0, 0, 0);
    if (!settings->get("main/hide_toolbar").toBool())
        layout->addWidget(m_navbar);
    layout->addWidget(m_view);
    setLayout(layout);
    show();
}

void Page::onUrlDenied(QString url)
{
    emit(urlDenied(url));
}

void Page::onEnd()
{
    emit(end());
}

void Page::adjustTitle(QString title)
{
    emit(titleChanged(title, this));
}

void Page::removeEmbedElements()
{
    QWebElementCollection elements = m_view->page()->mainFrame()->findAllElements("embed");
    foreach (QWebElement e, elements)
    {
        e.removeFromDocument();
    }
}
