#include <QDebug>

#include "settings.h"
#include "restrictedwebpage.h"
#include "restrictedwebview.h"

#include "ui_authDialog.h"

RestrictedWebView::RestrictedWebView(QUrl url, QWidget *parent)
    : QWebView(parent)
{
    RestrictedWebPage *page = new RestrictedWebPage(this);
    setPage(page);
    connect(page, &RestrictedWebPage::urlDenied, this, &RestrictedWebView::onUrlDenied);
    if (url.isValid())
        load(url);

    connect(page->networkAccessManager(),
            SIGNAL(authenticationRequired(QNetworkReply *, QAuthenticator *)),
            this, SLOT(onAuthRequired(QNetworkReply *, QAuthenticator *)));

    setContextMenuPolicy(Qt::NoContextMenu);

    installEventFilter(this);
}

QWebView *RestrictedWebView::createWindow(QWebPage::WebWindowType type)
{
    RestrictedWebView *webView = new RestrictedWebView(QUrl(),
                                        qobject_cast<QWidget *> (this->parent()));
    webView->show();
    emit(webViewCreated(webView));

    return webView;
}

void RestrictedWebView::onUrlDenied(QString str)
{
    emit(urlDenied(str));
}

bool RestrictedWebView::eventFilter(QObject *object, QEvent *event)
{
    if (event->type() == QEvent::MouseMove)
        emit(mouseMoved());

    return false;
}

void RestrictedWebView::home()
{
    QString s(Settings::load()->get("main/default_url").toString());
    load(QUrl(s));
}

void RestrictedWebView::onAuthRequired(QNetworkReply *reply, QAuthenticator *authenticator)
{
    QDialog *dialog = new QDialog;
    Ui::AuthDialog ui;
    ui.setupUi(dialog);

    if (dialog->exec() == QDialog::Accepted)
    {
        authenticator->setUser(ui.usernameEdit->text());
        authenticator->setPassword(ui.passwordEdit->text());
    }

    delete dialog;
}
