#include "pdf.h"

PDF::PDF(PlaylistItem *item, QWidget *parent)
    : QLabel(parent)
    , m_document(0)
{
    m_time = item->time();
    m_uri = item->uri().mid(7);
    m_document = Poppler::Document::load(m_uri);
    if (!m_document)
        emit(end());
    m_pageNb = -1;

    connect(&m_timer, &QTimer::timeout, this, &PDF::nextPage);
}

void PDF::setBlackBackground()
{
    QPalette p;
    p.setColor(QPalette::Background, Qt::black);
    QLabel::setAutoFillBackground(true);
    QLabel::setPalette(p);
}   

void PDF::nextPage()
{
    m_pageNb++;
    Poppler::Page *page = m_document->page(m_pageNb);
    m_timer.stop();
    if (! page)
        emit(end());

    QImage image = page->renderToImage();
    m_pixmap = QPixmap::fromImage(image);
    setPixmap(m_pixmap);
    setAlignment(Qt::AlignCenter);
    setBlackBackground();

    m_timer.start(1000 * m_time);

    delete page;
}

void PDF::run()
{
    nextPage();
}

void PDF::stop()
{
    m_timer.stop();
}
